@@ -572,3 +572,25 @@ PanasonicAudio1::PanasonicAudio1(
   addKaseikyoKey("panelclose", Unmapped_Key, 0xC2A, 0xF5); // "TOP_PANEL_CLOSE"
 }
 
+
+PanasonicAC1::PanasonicAC1(
+  QObject *guiObject,
+  unsigned int index)
+  : PIRKeysetMetaData(
+      "Air Conditioner 1",
+      Panasonic_Make,
+      index)
+{
+  threadableProtocol = new NECProtocol(guiObject, index, true, true);
+
+  setPreData(0x6681, 16);
+
+  addKey("Operation", Power_Key, 0x81, 8);
+  addKey("Air Swing", Yellow_Key, 0x83, 8);
+  addKey("Temp Up", Red_Key, 0x85, 8);
+  addKey("Temp Down", Blue_Key, 0x8A, 8);
+  addKey("Economy", Green_Key, 0x8D, 8);
+  addKey("Timer", Sleep_Key, 0x90, 8);
+  addKey("Fan Speed", SoundMode_Key, 0x99, 8);
+  addKey("Mode", PictureMode_Key, 0x9B, 8);
+}
