@@ -29,7 +29,15 @@ public:
     unsigned int index);
 };
 
-class ToshibaTV1c: public ToshibaTV1
+class ToshibaTV1f: public ToshibaTV1
+{
+public:
+  ToshibaTV1f(
+    QObject *guiObject,
+    unsigned int index);
+};
+
+class ToshibaTV1c: public ToshibaTV1f
 {
 public:
   ToshibaTV1c(
@@ -37,7 +45,7 @@ public:
     unsigned int index);
 };
 
-class ToshibaTV1d: public ToshibaTV1
+class ToshibaTV1d: public ToshibaTV1f
 {
 public:
   ToshibaTV1d(
@@ -53,14 +61,6 @@ public:
     unsigned int index);
 };
 
-class ToshibaTV1f: public ToshibaTV1
-{
-public:
-  ToshibaTV1f(
-    QObject *guiObject,
-    unsigned int index);
-};
-
 class ToshibaTV1g: public ToshibaTV1
 {
 public:
@@ -69,6 +69,14 @@ public:
     unsigned int index);
 };
 
+class ToshibaTV1h: public ToshibaTV1b
+{
+public:
+  ToshibaTV1h(
+    QObject *guiObject,
+    unsigned int index);
+};
+
 class ToshibaVCR1: public PIRKeysetMetaData
 {
 public:
