@@ -14,6 +14,7 @@
 #include "keysets/daewoo.h"
 #include "keysets/denon.h"
 #include "keysets/digitalstream.h"
+#include "keysets/directv.h"
 #include "keysets/dish.h"
 #include "keysets/ei.h"
 #include "keysets/elgato.h"
@@ -106,6 +107,7 @@ PIRKeysetManager::PIRKeysetManager(
   populateKeyset(new BoseRadio1(guiObject, counter++));
   populateKeyset(new BoseRadio2(guiObject, counter++));
   populateKeyset(new BoseRadio3(guiObject, counter++));
+  populateKeyset(new BoseHomeTheater1(guiObject, counter++));
 
   populateKeyset(new CambridgeCD1(guiObject, counter++));
   populateKeyset(new CambridgeAudio1(guiObject, counter++));
@@ -145,6 +147,8 @@ PIRKeysetManager::PIRKeysetManager(
 
   populateKeyset(new DigitalStreamReceiver(guiObject, counter++));
 
+  populateKeyset(new DirectvReceiver1(guiObject, counter++));
+
   populateKeyset(new DishReceiver1(guiObject, counter++));
   populateKeyset(new DishReceiver1a(guiObject, counter++));
   populateKeyset(new DishReceiver1b(guiObject, counter++));
@@ -254,6 +258,7 @@ PIRKeysetManager::PIRKeysetManager(
   populateKeyset(new LGVCR1(guiObject, counter++));
   populateKeyset(new LGVCR1a(guiObject, counter++));
   populateKeyset(new LGVCR1b(guiObject, counter++));
+  populateKeyset(new LGAC1(guiObject, counter++));
 
   populateKeyset(new LogitechSpeakers(guiObject, counter++));
 
@@ -291,6 +296,7 @@ PIRKeysetManager::PIRKeysetManager(
   populateKeyset(new PanasonicDVD1(guiObject, counter++));
   populateKeyset(new PanasonicDVD1a(guiObject, counter++));
   populateKeyset(new PanasonicAudio1(guiObject, counter++));
+  populateKeyset(new PanasonicAC1(guiObject, counter++));
 
   populateKeyset(new PhilcoTV(guiObject, counter++));
 
@@ -392,6 +398,7 @@ PIRKeysetManager::PIRKeysetManager(
   populateKeyset(new SamsungDVD1b(guiObject, counter++));
   populateKeyset(new SamsungDVD2(guiObject, counter++));
   populateKeyset(new SamsungAC1(guiObject, counter++));
+  populateKeyset(new SamsungDVBT1(guiObject, counter++));
 
   populateKeyset(new SanyoVCR1(guiObject, counter++));
   populateKeyset(new SanyoDVD1(guiObject, counter++));
